Bv2.1 7.2.3: Check that subtitle <StartTime> exists and is 0.
[libdcp.git] / src / dcp.h
index 9c97e6aa2bcafd6f15898efd7f12fe7e9a9d8360..3eab743ec8453560dd3e825ee786640a6932e9d0 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2012-2014 Carl Hetherington <cth@carlh.net>
+    Copyright (C) 2012-2020 Carl Hetherington <cth@carlh.net>
 
     This file is part of libdcp.
 
 #ifndef LIBDCP_DCP_H
 #define LIBDCP_DCP_H
 
+#include "compose.hpp"
 #include "types.h"
 #include "util.h"
 #include "certificate.h"
 #include "metadata.h"
 #include "name_format.h"
-#include <boost/shared_ptr.hpp>
+#include "verify.h"
+#include "version.h"
+#include <memory>
 #include <boost/signals2.hpp>
 #include <string>
 #include <vector>
@@ -61,11 +64,10 @@ class PKL;
 class Content;
 class Reel;
 class CPL;
-class XMLMetadata;
 class CertificateChain;
 class DecryptedKDM;
 class Asset;
-class DCPReadError;
+class ReadError;
 
 /** @class DCP
  *  @brief A class to create or read a DCP.
@@ -83,16 +85,13 @@ public:
         */
        explicit DCP (boost::filesystem::path directory);
 
-       typedef std::list<boost::shared_ptr<DCPReadError> > ReadErrors;
-
        /** Read the DCP's structure into this object.
-        *  @param keep_going true to try to keep going in the face of (some) errors.
-        *  @param errors List of errors that will be added to if keep_going is true.
+        *  @param notes List of notes that will be added to if non-0.
         *  @param ignore_incorrect_picture_mxf_type true to try loading MXF files marked as monoscopic
         *  as stereoscopic if the monoscopic load fails; fixes problems some 3D DCPs that (I think)
         *  have an incorrect descriptor in their MXF.
         */
-       void read (bool keep_going = false, ReadErrors* errors = 0, bool ignore_incorrect_picture_mxf_type = false);
+       void read (std::list<VerificationNote>* notes = 0, bool ignore_incorrect_picture_mxf_type = false);
 
        /** Compare this DCP with another, according to various options.
         *  @param other DCP to compare this one to.
@@ -102,10 +101,10 @@ public:
         */
        bool equals (DCP const & other, EqualityOptions options, NoteHandler note) const;
 
-       void add (boost::shared_ptr<CPL> cpl);
+       void add (std::shared_ptr<CPL> cpl);
 
-       std::list<boost::shared_ptr<CPL> > cpls () const;
-       std::list<boost::shared_ptr<Asset> > assets (bool ignore_unresolved = false) const;
+       std::list<std::shared_ptr<CPL> > cpls () const;
+       std::list<std::shared_ptr<Asset> > assets (bool ignore_unresolved = false) const;
 
        bool encrypted () const;
 
@@ -113,12 +112,15 @@ public:
 
        void write_xml (
                Standard standard,
-               XMLMetadata metadata = XMLMetadata (),
-               boost::shared_ptr<const CertificateChain> signer = boost::shared_ptr<const CertificateChain> (),
+               std::string issuer = String::compose("libdcp %1", dcp::version),
+               std::string creator = String::compose("libdcp %1", dcp::version),
+               std::string issue_date = LocalTime().as_string(),
+               std::string annotation_text = String::compose("Created by libdcp %1", dcp::version),
+               std::shared_ptr<const CertificateChain> signer = std::shared_ptr<const CertificateChain> (),
                NameFormat name_format = NameFormat("%t")
        );
 
-       void resolve_refs (std::list<boost::shared_ptr<Asset> > assets);
+       void resolve_refs (std::list<std::shared_ptr<Asset> > assets);
 
        /** @return Standard of a DCP that was read in */
        boost::optional<Standard> standard () const {
@@ -129,11 +131,15 @@ public:
                return _directory;
        }
 
/** @return PKL if this DCP was read from an existing one, or if write_xml() has been called on it.
*  If neither is true, this method returns 0.
         */
-       boost::shared_ptr<PKL> pkl () const {
-               return _pkl;
+       std::list<std::shared_ptr<PKL> > pkls () const {
+               return _pkls;
+       }
+
+       boost::optional<boost::filesystem::path> asset_map_path () {
+               return _asset_map;
        }
 
        static std::vector<boost::filesystem::path> directories_from_files (std::vector<boost::filesystem::path> files);
@@ -146,13 +152,19 @@ private:
         *  @param pkl_uuid UUID of our PKL.
         *  @param pkl_path Pathname of our PKL file.
         */
-       void write_assetmap (Standard standard, std::string pkl_uuid, boost::filesystem::path pkl_path, XMLMetadata metadata) const;
+       void write_assetmap (
+               Standard standard, std::string pkl_uuid, boost::filesystem::path pkl_path,
+               std::string issuer, std::string creator, std::string issue_date, std::string annotation_text
+               ) const;
 
-       /** the directory that we are writing to */
+       /** The directory that we are writing to */
        boost::filesystem::path _directory;
-       /** the CPLs that make up this DCP */
-       std::list<boost::shared_ptr<CPL> > _cpls;
-       boost::shared_ptr<PKL> _pkl;
+       /** The CPLs that make up this DCP */
+       std::list<std::shared_ptr<CPL> > _cpls;
+       /** The PKLs that make up this DCP */
+       std::list<std::shared_ptr<PKL> > _pkls;
+       /** File that the ASSETMAP was read from or last written to */
+       mutable boost::optional<boost::filesystem::path> _asset_map;
 
        /** Standard of DCP that was read in */
        boost::optional<Standard> _standard;
@@ -129,11 +131,15 @@ public:
        }
 
-       /** @return PKL if this DCP was read from an existing one, or if write_xml() has been called on it.
-        *  If neither is true, this method returns 0.
+       /** @return PKLs if this DCP was read from an existing one, or if write_xml() has been called on it.
+        *  If neither is true, this method returns an empty list.
         */